// typedef QueryKey dynamic;

// typedef ArrayQueryKey List<QueryKey>;

import 'dart:math';

import 'package:flutter_query/src/query_cache.dart';

// TODO: Convert this
// typedef TypedQueryFunction<
//   TResult,
//   TArgs extends TypedQueryFunctionArgs = TypedQueryFunctionArgs
// > = (...args: TArgs) => TResult | Promise<TResult>;

class BaseQueryConfig {
  /**
   * If `false`, failed queries will not retry by default.
   * If `true`, failed queries will retry infinitely., failureCount: num
   * If set to an integer number, e.g. 3, failed queries will retry until the failed query count meets that number.
   * If set to a function `(failureCount, error) => boolean` failed queries will retry until the function returns false.
   */
  dynamic retry;
  dynamic retryDelay;
  int cacheTime;
  // TODO: Convert this
  // isDataEqual?: (oldData: unknown, newData: unknown) => boolean
  Function isDataEqual;
  Function queryFn;
  dynamic queryKey;
  Function queryKeySerializerFn;
  // TODO: Convert this
  // queryFnParamsFilter?: (args: ArrayQueryKey) => ArrayQueryKey
  Function queryFnParamsFilter;
  // TODO: Convert this
  // initialData?: TResult | InitialDataFunction<TResult>
  dynamic initialData;
  var infinite = true;
  /**
   * Set this to `false` to disable structural sharing between query results.
   * Defaults to `true`.
   */
  bool structuralSharing;
  /**
   * This function can be set to automatically get the next cursor for infinite queries.
   * The result will also be used to determine the value of `canFetchMore`.
   */
  // TODO: Convert this
  // getFetchMore?: (lastPage: TData, allPages: TData[]) => unknown
  Function getFetchMore;

  BaseQueryConfig({
    this.retry,
    this.retryDelay,
    this.cacheTime = 5 * 60 * 1000,
    this.isDataEqual,
    this.queryFn,
    this.queryKey,
    this.queryKeySerializerFn,
    this.queryFnParamsFilter,
    this.initialData,
    this.infinite,
    this.structuralSharing,
    this.getFetchMore,
  });
}

class QueryObserverConfig extends BaseQueryConfig {
  dynamic retry;
  dynamic retryDelay;
  int cacheTime;
  // TODO: Convert this
  // isDataEqual?: (oldData: unknown, newData: unknown) => boolean
  Function isDataEqual;
  Function queryFn;
  Function queryKeySerializerFn;
  // TODO: Convert this
  // queryFnParamsFilter?: (args: ArrayQueryKey) => ArrayQueryKey
  Function queryFnParamsFilter;
  // TODO: Convert this
  // initialData?: TResult | InitialDataFunction<TResult>
  dynamic initialData;
  var infinite = true;
  /**
   * Set this to `false` to disable structural sharing between query results.
   * Defaults to `true`.
   */
  bool structuralSharing;
  /**
   * This function can be set to automatically get the next cursor for infinite queries.
   * The result will also be used to determine the value of `canFetchMore`.
   */
  // TODO: Convert this
  // getFetchMore?: (lastPage: TData, allPages: TData[]) => unknown
  Function getFetchMore;

  /**
   * Set this to `false` to disable automatic refetching when the query mounts or changes query keys.
   * To refetch the query, use the `refetch` method returned from the `useQuery` instance.
   * Defaults to `true`.
   */
  bool enabled;
  /**
   * The time in milliseconds after data is considered stale.
   * If set to `Infinity`, the data will never be stale.
   */
  double staleTime;
  /**
   * If set, this will mark any `initialData` provided as stale and will likely cause it to be refetched on mount.
   * If a function is passed, it will be called only when appropriate to resolve the `initialStale` value.
   * This can be useful if your `initialStale` value is costly to calculate.
   */
  dynamic initialStale;
  /**
   * If set to a number, the query will continuously refetch at this frequency in milliseconds.
   * Defaults to `false`.
   */
  dynamic refetchInterval;
  /**
   * If set to `true`, the query will continue to refetch while their tab/window is in the background.
   * Defaults to `false`.
   */
  bool refetchIntervalInBackground;
  /**
   * If set to `true`, the query will refetch on reconnect if the data is stale.
   * If set to `false`, the query will not refetch on reconnect.
   * If set to `'always'`, the query will always refetch on reconnect.
   * Defaults to `true`.
   */
  dynamic refetchOnReconnect;
  /**
   * If set to `true`, the query will refetch on mount if the data is stale.
   * If set to `false`, will disable additional instances of a query to trigger background refetches.
   * If set to `'always'`, the query will always refetch on mount.
   * Defaults to `true`.
   */
  dynamic refetchOnMount;
  /**
   * Set this to `true` to always fetch when the component mounts (regardless of staleness).
   * Defaults to `false`.
   */
  bool forceFetchOnMount;
  /**
   * Whether a change to the query status should re-render a component.
   * If set to `false`, the component will only re-render when the actual `data` or `error` changes.
   * Defaults to `true`.
   */
  bool notifyOnStatusChange;
  /**
   * This callback will fire any time the query successfully fetches new data.
   */
  Function onSuccess;
  /**
   * This callback will fire if the query encounters an error and will be passed the error.
   */
  Function onError;
  /**
   * This callback will fire any time the query is either successfully fetched or errors and be passed either the data or error.
   */
  Function onSettled;
  /**
   * Whether errors should be thrown instead of setting the `error` property.
   * Defaults to `false`.
   */
  bool useErrorBoundary;
  /**
   * Set this to `true` to keep the previous `data` when fetching based on a new query key.
   * Defaults to `false`.
   */
  bool keepPreviousData;

  QueryObserverConfig({
    // Super
    this.retry,
    this.retryDelay,
    this.cacheTime = 5 * 60 * 1000,
    this.isDataEqual,
    this.queryFn,
    this.queryKeySerializerFn,
    this.queryFnParamsFilter,
    this.initialData,
    this.infinite,
    this.structuralSharing,
    this.getFetchMore,

    // This
    this.enabled,
    this.staleTime,
    this.initialStale,
    this.refetchInterval,
    this.refetchIntervalInBackground,
    this.refetchOnReconnect,
    this.refetchOnMount,
    this.forceFetchOnMount,
    this.notifyOnStatusChange,
    this.onSuccess,
    this.onError,
    this.onSettled,
    this.useErrorBoundary,
    this.keepPreviousData,
  });
}

// TODO: Address whether or not we need these config types

// class QueryConfig extends QueryObserverConfig {}
// class PaginatedQueryConfig extends QueryObserverConfig {}
// class InfiniteQueryConfig extends QueryObserverConfig {}

class ResolvedQueryConfig extends QueryObserverConfig {
  int cacheTime;
  QueryCache queryCache;
  Function queryFn;
  Function queryKeySerializerFn;
  dynamic initialData;
  String queryHash;
  dynamic queryKey;
  double staleTime;

  dynamic retry;
  dynamic retryDelay =
      (attemptIndex) => min(pow(1000 * 2, attemptIndex), 30000);
  Function isDataEqual;
  Function queryFnParamsFilter;
  Function getFetchMore;
  dynamic initialStale;
  dynamic refetchInterval;
  dynamic refetchOnReconnect;
  dynamic refetchOnMount;
  Function onSuccess;
  Function onError;
  Function onSettled;

  bool infinite;
  bool structuralSharing;
  bool enabled;
  bool refetchIntervalInBackground;
  bool forceFetchOnMount;
  bool notifyOnStatusChange;
  bool useErrorBoundary;
  bool keepPreviousData;

  ResolvedQueryConfig({
    this.queryCache,
    this.queryHash,
    this.queryKey,
    this.cacheTime = 5 * 60 * 1000,
    this.queryFn,
    this.queryKeySerializerFn,
    this.initialData,
    this.staleTime = 0,

    // Split
    this.enabled = true,
    this.initialStale,
    this.refetchInterval,
    this.refetchIntervalInBackground = true,
    this.refetchOnReconnect = true,
    this.refetchOnMount = true,
    this.forceFetchOnMount = false,
    this.notifyOnStatusChange = true,
    this.onSuccess,
    this.onError,
    this.onSettled,
    this.useErrorBoundary = false,
    this.keepPreviousData = false,
    this.retry = 3,
    this.retryDelay,
    this.isDataEqual,
    this.queryFnParamsFilter,
    this.infinite = false,
    this.structuralSharing = true,
    this.getFetchMore,
  });
}

// export type TypedQueryFunctionArgs = readonly [unknown, ...unknown[]]

// export type InitialDataFunction<TResult> = () => TResult | undefined

// export type InitialStaleFunction = () => boolean

// export type QueryKeySerializerFunction = (
//   queryKey: QueryKey
// ) => [string, QueryKey[]]

// export type IsFetchingMoreValue = 'previous' | 'next' | false

enum QueryStatus {
  Idle,
  Loading,
  Error,
  Success,
}

class QueryResultBase {
  bool canFetchMore;
  Function clear;
  dynamic data;
  dynamic error;
  int failureCount;
  Function fetchMore;
  bool isError;
  bool isFetched;
  bool isFetchedAfterMount;
  bool isFetching;
  dynamic isFetchingMore;
  bool isIdle;
  bool isInitialData;
  bool isLoading;
  bool isPreviousData;
  bool isStale;
  bool isSuccess;
  Function refetch;
  Function remove;
  QueryStatus status;
  int updatedAt;
}

class QueryResult extends QueryResultBase {
  bool canFetchMore;
  Function clear;
  dynamic data;
  dynamic error;
  int failureCount;
  Function fetchMore;
  bool isFetched;
  bool isFetchedAfterMount;
  bool isFetching;
  dynamic isFetchingMore;
  bool isInitialData;
  bool isPreviousData;
  bool isStale;
  Function refetch;
  Function remove;
  QueryStatus status;
  int updatedAt;

  bool get isLoading {
    return status == QueryStatus.Loading;
  }

  bool get isSuccess {
    return status == QueryStatus.Success;
  }

  bool get isError {
    return status == QueryStatus.Error;
  }

  bool get isIdle {
    return status == QueryStatus.Idle;
  }

  QueryResult({
    this.canFetchMore,
    this.clear,
    this.data,
    this.error,
    this.failureCount,
    this.fetchMore,
    this.isFetched,
    this.isFetchedAfterMount,
    this.isFetching,
    this.isFetchingMore,
    this.isInitialData,
    this.isPreviousData,
    this.isStale,
    this.refetch,
    this.remove,
    this.status,
    this.updatedAt,
  });
}

class PaginatedQueryResult extends QueryResultBase {
  dynamic resolvedData;
  dynamic latestData;
}

class InfiniteQueryResult extends QueryResultBase {}

class MutateConfig<TResult, TError, TVariables, TSnapshot> {
  Function onSuccess;
  Function onError;
  Function onSettled;
  bool throwOnError;
}

class MutationConfig<TResult, TError, TVariables, TSnapshot>
    extends MutateConfig<TResult, TError, TVariables, TSnapshot> {
  Function onMutate;
  bool useErrorBoundary;
  /**
   * By default the query cache from the context is used, but a different cache can be specified.
   */
  QueryCache queryCache;
}

// export type MutationFunction<TResult, TVariables = unknown> = (
//   variables: TVariables
// ) => Promise<TResult>

// export type MutateFunction<
//   TResult,
//   TError = unknown,
//   TVariables = unknown,
//   TSnapshot = unknown
// > = (
//   variables?: TVariables,
//   config?: MutateConfig<TResult, TError, TVariables, TSnapshot>
// ) => Promise<TResult | undefined>

// export type MutationResultPair<TResult, TError, TVariables, TSnapshot> = [
//   MutateFunction<TResult, TError, TVariables, TSnapshot>,
//   MutationResult
// ]

class MutationResult {
  QueryStatus status;
  dynamic data;
  dynamic error;
  bool isIdle;
  bool isLoading;
  bool isSuccess;
  bool isError;
  Function reset;
}

class ReactQueryConfig {
  QueryObserverConfig queries;
  ReactQuerySharedConfig shared;
  // TODO: Convert this
  ReactQueryMutationsConfig mutations;

  ReactQueryConfig({this.queries, this.shared, this.mutations});
}

// TODO: Convert this
class ReactQueryQueriesConfig extends QueryObserverConfig {
  ReactQueryQueriesConfig();
}

class ReactQuerySharedConfig {}

class ReactQueryMutationsConfig<TResult, TError, TVariables, TSnapshot>
    extends MutationConfig<TResult, TError, TVariables, TSnapshot> {}
